@@ -6,7 +6,6 @@ def randomInt_Integers(fromInt,toInt):
     randomnumber = random.randint(fromInt,toInt)
     return randomnumber
 def randomInt_type_MaxMinNumber():
-    global list_max
     #使用循环取值支持输入，并检测异常，冒泡输入8位
     list_1 = list()
     try:
@@ -15,18 +14,10 @@ def randomInt_type_MaxMinNumber():
             list_1.append(num)
         print(list_1)
         c = list_1[0]
-        for i in list_1:
-            if c!=i:
-                if c<i:
-                    c=i
-                    list_max=i
-        for b in list_1:
-            if b!=c:
-                if c>b:
-                    c=b
-                    list_min=c
-        print(list_max)
-        print(list_min)
+        list_max = max(list_1)
+        list_min = min(list_1)
+        print('max:',list_max)
+        print('min:',list_min)
     except Exception as e:
         print(e)
     return
